<div class="peek-nav-section"></div>

<div class="peek-nav-bar-padding">
    <div class="peek-information-section">
        <p>
            Load Complete : {{lastStatus.initialLoadComplete}}<br />
            Load Progress :
            {{lastStatus.loadProgress}}/{{lastStatus.loadTotal}}<br />
            Last Check : {{lastStatus.lastCheck}}<br />
        </p>
    </div>
</div>
